.. toctree::
   :maxdepth: 3

   tensor_class

.. _tfuncs:

Tensor Compute Functions
==========================

.. currentmodule:: pytaco

.. autosummary::
   :toctree: functions

   tensor_abs
   tensor_square
   tensor_cube
   tensor_sqrt
   tensor_cube_root
   tensor_exp
   tensor_log
   tensor_log10
   tensor_sin
   tensor_cos
   tensor_tan
   tensor_asin
   tensor_acos
   tensor_atan
   tensor_atan2
   tensor_sinh
   tensor_cosh
   tensor_tanh
   tensor_asinh
   tensor_acosh
   tensor_atanh
   tensor_logical_not
   tensor_sum
   tensor_add
   tensor_mul
   tensor_div
   tensor_sub
   tensor_pow
   tensor_gt
   tensor_lt
   tensor_ge
   tensor_le
   tensor_eq
   tensor_ne
   tensor_max
   tensor_min
   tensor_heaviside
   as_type
   matmul
   inner
   dot
   outer
   tensordot

Tensor Manipulation Functions
===============================
.. currentmodule:: pytaco

.. autosummary::
   :toctree: functions

    tensor.transpose
    tensor.pack
    tensor.compile
    tensor.assemble
    tensor.compute
    tensor.evaluate
    tensor.to_dense
    tensor.to_array
    tensor.toarray
    tensor.to_sp_csr
    tensor.to_sp_csc
    tensor.copy
    tensor.insert
    tensor.remove_explicit_zeros
    remove_explicit_zeros
